@@ -2,7 +2,7 @@
 ##
 ## (C) 2007, 2008, 2013 Muthiah Annamalai <ezhillang@gmail.com>
 ## Licensed under GPL Version 3
-## Error Correction:msathia 2013<msathia@gmail.com>
+## (C) 2013 msathia <msathia@gmail.com>
 
 ## constants
 TA_ACCENT_LEN = 13 #12 + 1
@@ -13,6 +13,10 @@ TA_AGARAM_LEN = 18
 TA_SANSKRIT_LEN = 4
 TA_UYIRMEI_LEN = 216 # 18*12
 
+def  letters_to_py( _letters ):
+        """ return list of letters e.g. uyir_letters as a Python list """
+        return u"[u'"+u"',u'".join( _letters )+u"']"
+
 # List of letters you can use
 uyir_letters = [u"அ",u"ஆ",u"இ", 
 	u"ஈ",u"உ",u"ஊ",u"எ",u"ஏ",u"ஐ",u"ஒ",u"ஓ",u"ஔ"]
@@ -53,6 +57,20 @@ u"வ"  ,u"வா"  ,u"வி"  ,u"வீ"  ,u"வு"  ,u"வூ"  ,u"வெ"
 u"ழ"  ,u"ழா"  ,u"ழி"  ,u"ழீ"  ,u"ழு"  ,u"ழூ"  ,u"ழெ"  ,u"ழே"  ,u"ழை"  ,u"ழொ"  ,u"ழோ"  ,u"ழௌ" , 
 u"ள"  ,u"ளா"  ,u"ளி"  ,u"ளீ"  ,u"ளு"  ,u"ளூ"  ,u"ளெ"  ,u"ளே"  ,u"ளை"  ,u"ளொ"  ,u"ளோ"  ,u"ளௌ" ]
 
+# tamil symbols
+_day = u"௳"
+_month = u"௴"
+_year = u"௵"
+_debit = u"௶"
+_credit = u"௷"
+_rupee = u"௹"
+_numeral = u"௺"
+_sri = u"\u0bb6\u0bcd\u0bb0\u0bc0" #SRI - ஶ்ரீ
+_ksha = u"\u0b95\u0bcd\u0bb7" #KSHA - க்ஷ
+_ksh = u"\u0b95\u0bcd\u0bb7\u0bcd" #KSH - க்ஷ்
+
+tamil_symbols = [_day, _month, _year, _debit, _credit, _rupee, _numeral, _sri, _ksha, _ksh]
+
 ## total tamil letters in use, including sanskrit letters
 tamil_letters = [
 	
@@ -220,9 +238,73 @@ def get_letters( word ):
 				# plain-old ascii
 				ta_letters.append( c.decode('utf-8') )
 			else:
-				assert False #unknown/expected state
+                                # assertion is somewhat heavy handed here
+				print(u"Warning: #unknown/expected state - continuing tamil letter tokenizing. Copy unknown character to string output")
+                                ta_letters.append( c )
 	if prev != u'': #if prev is not null it is $c
 		ta_letters.append( prev )
 #print ta_letters
 #print u"".join(ta_letters)
 	return ta_letters
+
+# same as get_letters but use as iterable
+def get_letters_iterable( word ):
+	""" splits the word into a character-list of tamil/english
+	characters present in the stream """
+	prev = u''#word = unicode(word) #.encode('utf-8')
+	#word=word.decode('utf-8')
+	ta_letters = []
+	for c in word:
+		if c in uyir_letters or c == ayudha_letter:
+			yield (prev+c)
+			prev = u''
+		elif c in agaram_letters or c in sanskrit_letters:
+			if prev != u'':
+				yield (prev)
+			prev = c
+		elif c in accent_symbols:
+			yield (prev+c)
+			prev = u''
+		else:
+			if prev != u'':
+				yield (prev+c)
+				prev = u''
+			elif ord(c) < 256:
+				# plain-old ascii
+				yield ( c.decode('utf-8') )
+			else:
+                                # assertion is somewhat heavy handed here
+				print(u"Warning: #unknown/expected state - continuing tamil letter tokenizing. Copy unknown character to string output")
+                                yield c
+	if prev != u'': #if prev is not null it is $c
+		yield prev
+#print ta_letters
+#print u"".join(ta_letters)
+        raise StopIteration
+
+
+# அ ஆ இ ஈ உ ஊ எ ஏ ஐ ஒ ஓ ஔ ஃ 
+# க் ச் ட் த் ப் ற் ஞ் ங் ண் ந் ம் ன் ய் ர் ல் வ் ழ் ள் ஜ் ஷ் ஸ் ஹ் 
+# க ச ட த ப ற ஞ ங ண ந ம ன ய ர ல வ ழ ள ஜ ஷ ஸ ஹ 
+# க கா கி கீ கு கூ கெ கே கை  கௌ 
+# ச சா சி சீ சு சூ செ சே சை சொ சோ சௌ 
+# ட டா டி டீ டு டூ டெ டே டை டொ டோ டௌ 
+# த தா தி தீ து தூ தெ தே தை தொ தோ தௌ 
+# ப பா பி பீ பு பூ பெ பே பை பொ போ பௌ 
+# ற றா றி றீ று றூ றெ றே றை றொ றோ றௌ 
+# ஞ ஞா ஞி ஞீ ஞு ஞூ ஞெ ஞே ஞை ஞொ ஞோ ஞௌ 
+# ங ஙா ஙி ஙீ ஙு ஙூ ஙெ ஙே ஙை ஙொ ஙோ ஙௌ 
+# ண ணா ணி ணீ ணு ணூ ணெ ணே ணை ணொ ணோ ணௌ 
+# ந நா நி நீ நு நூ நெ நே நை நொ நோ நௌ 
+# ம மா மி மீ மு மூ மெ மே மை மொ மோ மௌ 
+# ன னா னி னீ னு னூ னெ னே னை னொ னோ னௌ 
+# ய யா யி யீ யு யூ யெ யே யை யொ யோ யௌ 
+# ர ரா ரி ரீ ரு ரூ ரெ ரே ரை ரொ ரோ ரௌ 
+# ல லா லி லீ லு லூ லெ லே லை லொ லோ லௌ 
+# வ வா வி வீ வு வூ வெ வே வை வொ வோ வௌ 
+# ழ ழா ழி ழீ ழு ழூ ழெ ழே ழை ழொ ழோ ழௌ
+# ள ளா ளி ளீ ளு ளூ ளெ ளே ளை ளொ ளோ ளௌ 
+# ஜ ஜா ஜி ஜீ ஜு ஜூ ஜெ ஜே ஜை ஜொ ஜோ ஜௌ 
+# ஷ ஷா ஷி ஷீ ஷு ஷூ ஷெ ஷே ஷை ஷொ ஷோ ஷௌ 
+# ஸ ஸா ஸி ஸீ ஸு ஸூ ஸெ ஸே ஸை ஸொ ஸோ ஸௌ 
+# ஹ ஹா ஹி ஹீ ஹு ஹூ ஹெ ஹே ஹை ஹொ ஹோ ஹௌ
